@@ -16,7 +16,7 @@ use App::Memcached::CLI::DataSource;
 use App::Memcached::CLI::Item;
 use App::Memcached::CLI::Util ':all';
 
-use version; our $VERSION = 'v0.5.4';
+use version; our $VERSION = 'v0.6.0';
 
 my $PROGRAM = basename $0;
 
@@ -185,10 +185,22 @@ sub help {
         +{
             command => 'stats',
             summary => 'Show stats',
+            description => <<'EODESC',
+Usage:
+    > stats [<REGEXP>]
+    > stats            # show all stats
+    > stats (hit|miss) # filter by REGEXP
+EODESC
         },
         +{
             command => 'settings',
             summary => 'Show settings',
+            description => <<'EODESC',
+Usage:
+    > settings [<REGEXP>]
+    > settings             # show all stats
+    > settings ^(lru|slab) # filter by REGEXP
+EODESC
         },
         +{
             command => 'cachedump',
@@ -421,39 +433,45 @@ sub display {
 }
 
 sub stats {
-    my $self = shift;
+    my $self   = shift;
+    my $filter = shift;
     my $response = $self->{ds}->query('stats');
-    my %stats;
-    for my $line (@$response) {
-        if ($line =~ m/^STAT\s+(\S*)\s+(.*)/) {
-            $stats{$1} = $2;
-        }
-    }
-    print "# stats - $self->{addr}\n";
-    printf "#%23s  %16s\n", 'Field', 'Value';
-    for my $field (sort {$a cmp $b} (keys %stats)) {
-        printf ("%24s  %16s\n", $field, $stats{$field});
-    }
+    _print_stats_of_response('stats', $filter, @$response);
     return 1;
 }
 
 sub settings {
     my $self = shift;
+    my $filter = shift;
     my $response = $self->{ds}->query('stats settings');
-    my %stats;
-    for my $line (@$response) {
-        if ($line =~ m/^STAT\s+(\S*)\s+(.*)/) {
-            $stats{$1} = $2;
-        }
-    }
-    print "# stats settings - $self->{addr}\n";
-    printf "#%23s  %16s\n", 'Field', 'Value';
-    for my $field (sort {$a cmp $b} (keys %stats)) {
-        printf ("%24s  %16s\n", $field, $stats{$field});
-    }
+    _print_stats_of_response('stats settings', $filter, @$response);
     return 1;
 }
 
+sub _print_stats_of_response {
+    my $title  = shift;
+    my $filter = shift;
+    my @lines  = @_;
+
+    my %stats;
+    my ($max_key_l, $max_val_l) = (0, 0);
+
+    for my $line (@lines) {
+        next if ($line !~ m/^STAT\s+(\S*)\s+(.*)/);
+        my ($key, $value) = ($1, $2);
+        if (length $key   > $max_key_l) { $max_key_l = length $key; }
+        if (length $value > $max_val_l) { $max_val_l = length $value; }
+        next if ($filter && $key !~ m/$filter/);
+        $stats{$key} = $value;
+    }
+
+    print  "# $title\n";
+    printf "#%${max_key_l}s  %${max_val_l}s\n", 'Field', 'Value';
+    for my $field (sort {$a cmp $b} (keys %stats)) {
+        printf (" %${max_key_l}s  %${max_val_l}s\n", $field, $stats{$field});
+    }
+}
+
 sub detaildump {
     my $self  = shift;
     my $response = $self->{ds}->query("stats detail dump");
